@@ -23,6 +23,7 @@ the local cached copy of the image file is returned.
 """
 
 import re
+import six
 
 from oslo_log import log as logging
 import webob
@@ -34,14 +35,12 @@ from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
 import glance.db
-from glance import i18n
+from glance.i18n import _LE, _LI
 from glance import image_cache
 from glance import notifier
 import glance.registry.client.v1.api as registry
 
 LOG = logging.getLogger(__name__)
-_LI = i18n._LI
-_LE = i18n._LE
 
 PATTERNS = {
     ('v1', 'GET'): re.compile(r'^/v1/images/([^\/]+)$'),
@@ -78,7 +77,7 @@ class CacheFilter(wsgi.Middleware):
     def _match_request(request):
         """Determine the version of the url and extract the image id
 
-        :returns tuple of version and image id if the url is a cacheable,
+        :returns: tuple of version and image id if the url is a cacheable,
                  otherwise None
         """
         for ((version, method), pattern) in PATTERNS.items():
@@ -239,7 +238,9 @@ class CacheFilter(wsgi.Middleware):
         # content-length got by the method "download" because of this issue:
         # https://github.com/Pylons/webob/issues/86
         response.headers['Content-Type'] = 'application/octet-stream'
-        response.headers['Content-MD5'] = image.checksum
+        if image.checksum:
+            response.headers['Content-MD5'] = (image.checksum.encode('utf-8')
+                                               if six.PY2 else image.checksum)
         response.headers['Content-Length'] = str(image.size)
         return response
 
