@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
@@ -29,14 +28,11 @@ from glance.common import exception
 from glance.common import wsgi
 from glance.common import wsme_utils
 import glance.db
-from glance import i18n
+from glance.i18n import _
 import glance.notifier
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-
-CONF = cfg.CONF
 
 
 class MetadefObjectsController(object):
@@ -62,6 +58,10 @@ class MetadefObjectsController(object):
             LOG.debug("User not permitted to create metadata object within "
                       "'%s' namespace", namespace)
             raise webob.exc.HTTPForbidden(explanation=e.msg)
+        except exception.Invalid as e:
+            msg = (_("Couldn't create metadata object: %s")
+                   % encodeutils.exception_to_unicode(e))
+            raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.NotFound as e:
             raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Duplicate as e:
@@ -133,6 +133,10 @@ class MetadefObjectsController(object):
             metadef_object.properties = wsme_utils._get_value(
                 metadata_object.properties)
             updated_metadata_obj = meta_repo.save(metadef_object)
+        except exception.Invalid as e:
+            msg = (_("Couldn't update metadata object: %s")
+                   % encodeutils.exception_to_unicode(e))
+            raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.Forbidden as e:
             LOG.debug("User not permitted to update metadata object '%s' "
                       "within '%s' namespace ", object_name, namespace)
@@ -173,7 +177,8 @@ def _get_base_definitions():
 def _get_base_properties():
     return {
         "name": {
-            "type": "string"
+            "type": "string",
+            "maxLength": 255
         },
         "description": {
             "type": "string"
@@ -185,21 +190,23 @@ def _get_base_properties():
             "$ref": "#/definitions/property"
         },
         "schema": {
+            'readOnly': True,
             "type": "string"
         },
         "self": {
+            'readOnly': True,
             "type": "string"
         },
         "created_at": {
             "type": "string",
-            "description": _("Date and time of object creation"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of object creation"),
             "format": "date-time"
         },
         "updated_at": {
             "type": "string",
-            "description": _("Date and time of the last object modification"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of the last object modification"),
             "format": "date-time"
         }
     }
@@ -293,6 +300,19 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
 
         return filters
 
+    def _validate_limit(self, limit):
+        try:
+            limit = int(limit)
+        except ValueError:
+            msg = _("limit param must be an integer")
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+
+        if limit <= 0:
+            msg = _("limit param must be positive")
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+
+        return limit
+
     @classmethod
     def _check_allowed(cls, image):
         for key in cls._disallowed_properties:
