@@ -55,7 +55,6 @@ from glance.i18n import _
 
 
 CONF = cfg.CONF
-LOG = logging.getLogger(__name__)
 
 
 # Decorators for actions
@@ -85,17 +84,6 @@ class DbCommands(object):
                           db_migration.MIGRATE_REPO_PATH,
                           version)
 
-    @args('--version', metavar='<version>', help='Database version')
-    def downgrade(self, version=None):
-        """Downgrade the database's migration level"""
-        print("Warning: DB downgrade is deprecated and will be removed in N "
-              "release. Users should make a full database backup of the "
-              "production data before attempting any upgrade.",
-              file=sys.stderr)
-        migration.db_sync(db_api.get_engine(),
-                          db_migration.MIGRATE_REPO_PATH,
-                          version)
-
     @args('--version', metavar='<version>', help='Database version')
     def version_control(self, version=None):
         """Place a database under migration control"""
@@ -108,7 +96,7 @@ class DbCommands(object):
           help='Current Database version')
     def sync(self, version=None, current_version=None):
         """
-        Place a database under migration control and upgrade/downgrade it,
+        Place a database under migration control and upgrade it,
         creating first if necessary.
         """
         if current_version not in (None, 'None'):
@@ -157,8 +145,18 @@ class DbCommands(object):
           help='Limit number of records to delete')
     def purge(self, age_in_days=30, max_rows=100):
         """Purge deleted rows older than a given age from glance tables."""
-        age_in_days = int(age_in_days)
-        max_rows = int(max_rows)
+        try:
+            age_in_days = int(age_in_days)
+        except ValueError:
+            sys.exit(_("Invalid int value for age_in_days: "
+                       "%(age_in_days)s") % {'age_in_days': age_in_days})
+
+        try:
+            max_rows = int(max_rows)
+        except ValueError:
+            sys.exit(_("Invalid int value for max_rows: "
+                       "%(max_rows)s") % {'max_rows': max_rows})
+
         if age_in_days <= 0:
             sys.exit(_("Must supply a positive, non-zero value for age."))
         if age_in_days >= (int(time.time()) / 86400):
@@ -166,7 +164,10 @@ class DbCommands(object):
         if max_rows < 1:
             sys.exit(_("Minimal rows limit is 1."))
         ctx = context.get_admin_context(show_deleted=True)
-        db_api.purge_deleted_rows(ctx, age_in_days, max_rows)
+        try:
+            db_api.purge_deleted_rows(ctx, age_in_days, max_rows)
+        except exception.Invalid as exc:
+            sys.exit(exc.msg)
 
 
 class DbLegacyCommands(object):
@@ -181,13 +182,6 @@ class DbLegacyCommands(object):
     def upgrade(self, version=None):
         self.command_object.upgrade(CONF.command.version)
 
-    def downgrade(self, version=None):
-        print("Warning: DB downgrade is deprecated and will be removed in N "
-              "release. Users should make a full database backup of the "
-              "production data before attempting any upgrade.",
-              file=sys.stderr)
-        self.command_object.downgrade(CONF.command.version)
-
     def version_control(self, version=None):
         self.command_object.version_control(CONF.command.version)
 
@@ -222,11 +216,6 @@ def add_legacy_command_parsers(command_object, subparsers):
     parser.add_argument('version', nargs='?')
     parser.set_defaults(action='db_upgrade')
 
-    parser = subparsers.add_parser('db_downgrade')
-    parser.set_defaults(action_fn=legacy_command_object.downgrade)
-    parser.add_argument('version')
-    parser.set_defaults(action='db_downgrade')
-
     parser = subparsers.add_parser('db_version_control')
     parser.set_defaults(action_fn=legacy_command_object.version_control)
     parser.add_argument('version', nargs='?')
