@@ -56,7 +56,7 @@ def _db_fixture(task_id, **kwargs):
         'result': None,
         'owner': None,
         'message': None,
-        'expires_at': None,
+        'expires_at': default_datetime + datetime.timedelta(days=365),
         'created_at': default_datetime,
         'updated_at': default_datetime,
         'deleted_at': None,
@@ -371,7 +371,6 @@ class TestTasksController(test_utils.BaseTestCase):
         wrong_import_from = [
             "swift://cloud.foo/myaccount/mycontainer/path",
             "file:///path",
-            "s3://accesskey:secretkey@s3.amazonaws.com/bucket/key-id",
             "cinder://volume-id"
         ]
         executor_factory = self.gateway.get_task_executor_factory(
@@ -407,6 +406,28 @@ class TestTasksController(test_utils.BaseTestCase):
                        "%(supported)s") % {'supported': supported}
             self.assertEqual(msg, final_task.message)
 
+    def test_create_with_properties_missed(self):
+        request = unit_test_utils.get_fake_request()
+        executor_factory = self.gateway.get_task_executor_factory(
+            request.context)
+        task_repo = self.gateway.get_task_repo(request.context)
+
+        task = {
+            "type": "import",
+            "input": {
+                "import_from": "swift://cloud.foo/myaccount/mycontainer/path",
+                "import_from_format": "qcow2",
+            }
+        }
+        new_task = self.controller.create(request, task=task)
+        task_executor = executor_factory.new_task_executor(request.context)
+        task_executor.begin_processing(new_task.task_id)
+        final_task = task_repo.get(new_task.task_id)
+
+        self.assertEqual('failure', final_task.status)
+        msg = "Input does not contain 'image_properties' field"
+        self.assertEqual(msg, final_task.message)
+
     @mock.patch.object(glance.gateway.Gateway, 'get_task_factory')
     def test_notifications_on_create(self, mock_get_task_factory):
         request = unit_test_utils.get_fake_request()
